list_trend_table_sheets: List Available Sheets in Trend Table

View source: R/read_trend_table.R

list_trend_table_sheetsR Documentation

List Available Sheets in Trend Table

Description

Lists all available sheets in a HCUP Summary Trend Table Excel file.

Usage

list_trend_table_sheets(file_path)

Arguments

file_path

Character string, path to a trend table Excel file (.xlsx).

Value

A character vector of sheet names.

Examples


# Requires network: download first, then list sheets from that file path
path_xlsx <- download_trend_tables("2a")
list_trend_table_sheets(path_xlsx)



HCUPtools documentation built on July 13, 2026, 9:06 a.m.