View source: R/read_trend_table.R
| list_trend_table_sheets | R Documentation |
Lists all available sheets in a HCUP Summary Trend Table Excel file.
list_trend_table_sheets(file_path)
file_path |
Character string, path to a trend table Excel file (.xlsx). |
A character vector of sheet names.
# Requires network: download first, then list sheets from that file path
path_xlsx <- download_trend_tables("2a")
list_trend_table_sheets(path_xlsx)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.